Development
===========

To install all dependencies locally with ``pipenv``, run:

::

    pipenv install --three -e .

After the local virtual environment is created, run the following to "shell in" so that you can start making changes:

::

    pipenv shell